@@ -1,6 +1,8 @@
 import os
 from pathlib import Path
+from time import perf_counter
 
+from natsort import natsorted
 from nbclient import NotebookClient
 from nbformat import NO_CONVERT
 from nbformat import read as read_nb
@@ -34,24 +36,6 @@ def _list_nbs_in_md(nb_folder, md_filename="index.md"):
     return notebooks, names
 
 
-def pre_process_folder(nb_folder):
-    # Test whether prefix of a notebook is a capital letter or a digit and if so,
-    # strip them for pretty & persistent URLs.
-
-    # We need the prefixes on notebooks to allow users to navigate downloaded
-    # notebooks that should display in order in a file browser.
-
-    notebook_paths = [path for path in nb_folder.glob("*") if path.suffix == ".ipynb"]
-
-    for path in notebook_paths:
-        prefix = path.stem[0]
-        if prefix.isdigit() or prefix.isupper() and "-" in path.stem:
-            new_stem = "-".join(path.stem.split("-")[1:])
-            new_path = path.with_stem(new_stem)
-            path.rename(new_path)
-            print(f"renaming {path} -> {new_path}")
-
-
 def add_execution_count(nb):
     """Add consecutive execution count.
 
@@ -85,6 +69,8 @@ def execute_notebooks(nb_file_folder: Path, write: bool = True):
         nb_file_folder: Path to folder with notebooks or a notebook to execute.
         write: If `True`, write the execution results to the notebooks.
     """
+    t_execute_start = perf_counter()
+
     env = dict(os.environ)
 
     if nb_file_folder.is_file():
@@ -99,8 +85,6 @@ def execute_notebooks(nb_file_folder: Path, write: bool = True):
     else:
         nb_folder = nb_file_folder
 
-        pre_process_folder(nb_folder)
-
         # notebooks are part of documentation and indexed
         # by a sphinx myst index.md file
         # the order of execution matters!
@@ -115,9 +99,16 @@ def execute_notebooks(nb_file_folder: Path, write: bool = True):
                     print(f"Ignoring {name}.md due to special characters.")
                     continue
 
+        notebooks_unindexed = []
         for nb in nb_folder.glob("./*.ipynb"):
             if nb not in notebooks:
-                notebooks.append(nb)
+                notebooks_unindexed.append(nb)
+
+        # also for unindexed notebooks the order matters!!!
+        # we'll sort them with natsort so that they can be prefixed
+        notebooks += natsorted(notebooks_unindexed)
+
+    print(f"Will test these notebooks: {notebooks}")
 
     os.chdir(nb_folder)
 
@@ -125,7 +116,8 @@ def execute_notebooks(nb_file_folder: Path, write: bool = True):
         if ".ipynb_checkpoints/" in str(nb):
             continue
         nb_name = str(nb.relative_to(nb_folder))
-        print(f"{nb_name}")
+
+        t_start = perf_counter()
 
         nb_content = read_nb(nb, as_version=NO_CONVERT)
 
@@ -141,3 +133,10 @@ def execute_notebooks(nb_file_folder: Path, write: bool = True):
 
         if write:
             write_nb(nb_content, nb)
+
+        t_stop = perf_counter()
+
+        print(f"Executed {nb_name} in {(t_stop - t_start):.3f}s")
+
+    total_time_elapsed = perf_counter() - t_execute_start
+    print("It took %.3f seconds to execute all the notebooks" % total_time_elapsed)
